#include <ctype.h>
#include <string.h>
#include <stdlib.h>

#include "getbank.h"
#include "craps.h"

/* getBank 

   returns beginning bank roll or CRAPS_ERR_HELP or CRAPS_ERR_VERSION
   based on the contents of the commandline.
*/
int getBank(int count, char **value) {
    int n=0;
    int i=0;
    int option=0;  /* Boolean indicates option passed */
    int flagged=0; /* Boolean indicator for invalid characters */

    /* allow for only 0 or 1 parameters */

    if (count==1) return DEFAULT_BANK_ROLL;
    if (count>2) return CRAPS_ERR_PARAM;
    
    /* 
       Checks option for '?' and 'H' for help,
       also checks for 'V' for version.
       Throws away other valid option strings,
       Valid options consist of characters in {0-9,A-Z,a-z}.
     */
    if ((value[1][0]=='-')||(value[1][0]=='/')) option=1;
    if (option) {
      flagged=0;
      i=1;
      if (value[1][1]=='\0') flagged=1; /* no option after flag */
      while (value[1][i]!='\0') {
	if (!isalnum(value[1][i++])) /* invalid char after flag */
	  flagged=1;
      }
    } else {
      flagged=0;
      i=0;
      while (value[1][i]!='\0') {
	if (!isdigit(value[1][i++]))
	  flagged=1;
      } 
    }

    if (strcmp(value[1],"-H")==0) return CRAPS_ERR_HELP;
    if (strcmp(value[1],"-h")==0) return CRAPS_ERR_HELP;
    if (strcmp(value[1],"/H")==0) return CRAPS_ERR_HELP;
    if (strcmp(value[1],"/h")==0) return CRAPS_ERR_HELP;
    if (strcmp(value[1],"-?")==0) return CRAPS_ERR_HELP;
    if (strcmp(value[1],"/?")==0) return CRAPS_ERR_HELP;
    if (strcmp(value[1],"-V")==0) return CRAPS_ERR_VERSION;
    if (strcmp(value[1],"-v")==0) return CRAPS_ERR_VERSION;
    if (strcmp(value[1],"/V")==0) return CRAPS_ERR_VERSION;
    if (strcmp(value[1],"/v")==0) return CRAPS_ERR_VERSION;
    
    n = atoi(value[1]);
    if (n>MAX_BANK_ROLL) return CRAPS_ERR_RANGE;
    /* since we allow for negative, we need test for the negative out
       of range too */
    if ((n<0) && (n<MAX_BANK_ROLL*-1)) return CRAPS_ERR_RANGE;
    /* Minimum bank roll is 5 */
    if ((n>-5)&&(n<5)) return CRAPS_ERR_RANGE;
    
    if (flagged) return CRAPS_ERR_PARAM;
    if (option && !n) return CRAPS_ERR_HELP;
        
    return n;
} /* getBank */
